@@ -45,6 +45,19 @@ module.exports = {
 	// replaces file extension for another ( supplied)
 	file_ext: function(str, ext ){
 		return str.replace(/\.[^/.]+$/, ext);
+	}, 
+	
+	extend : function(destination, source) {
+	  for (var property in source) {
+		if (source[property] && source[property].constructor &&
+		 source[property].constructor === Object) {
+		  destination[property] = destination[property] || {};
+		  arguments.callee(destination[property], source[property]);
+		} else {
+		  destination[property] = source[property];
+		}
+	  }
+	  return destination;
 	}
 	
 };
\ No newline at end of file
